@@ -1,11 +1,21 @@
 # -*- python -*-
+# -*- coding: utf-8 -*-
 #
-#  Copyright 2013
+#  This file is part of the easydev software
+#
+#  Copyright (c) 2011-2014
 #
 #  File author(s): Thomas Cokelaer <cokelaer@gmail.com>
 #
-"""Common tools to get the correct filename and pathname. """
-__version__ = "$Rev: 60 $"
+#  Distributed under the GPLv3 License.
+#  See accompanying file LICENSE.txt or copy at
+#      http://www.gnu.org/licenses/gpl-3.0.html
+#
+#  Website: https://www.assembla.com/spaces/pyeasydev/wiki
+#  Documentation: http://packages.python.org/easydev
+#
+##############################################################################
+__version__ = "$Rev: 65 $"
 import pkg_resources
 try:
     version = pkg_resources.require("easydev")[0].version
@@ -16,8 +26,11 @@ import xfree86
 from xfree86 import *
 
 
-import colors
-from colors import *
+try:
+    import colors
+    from colors import *
+except:
+    print("colors module depends on pylab, which does not seem to be installed. skipped")
 
 import copybutton
 from copybutton import *
